@@ -147,6 +147,28 @@
 #endif
 
 
+/*
+ * MONGOC_ENABLE_SASL_CYRUS is set from configure to determine if we are
+ * compiled with Cyrus SASL support.
+ */
+#define MONGOC_ENABLE_SASL_CYRUS 1
+
+#if MONGOC_ENABLE_SASL_CYRUS != 1
+#  undef MONGOC_ENABLE_SASL_CYRUS
+#endif
+
+
+/*
+ * MONGOC_ENABLE_SASL_SSPI is set from configure to determine if we are
+ * compiled with SSPI support.
+ */
+#define MONGOC_ENABLE_SASL_SSPI 0
+
+#if MONGOC_ENABLE_SASL_SSPI != 1
+#  undef MONGOC_ENABLE_SASL_SSPI
+#endif
+
+
 /*
  * MONGOC_HAVE_SASL_CLIENT_DONE is set from configure to determine if we
  * have SASL and its version is new enough to use sasl_client_done (),
@@ -182,6 +204,15 @@
 #  undef MONGOC_NO_AUTOMATIC_GLOBALS
 #endif
 
+/*
+ * MONGOC_HAVE_SOCKLEN is set from configure to determine if we
+ * need to emulate the type.
+ */
+#define MONGOC_HAVE_SOCKLEN 1
+
+#if MONGOC_HAVE_SOCKLEN != 1
+#  undef MONGOC_HAVE_SOCKLEN
+#endif
 /*
  * NOTICE:
  * If you're about to update this file and add a config flag, make sure to
